@@ -250,8 +250,7 @@ typedef NSString *CALayerContentsGravity;
 
 -(BOOL)canBecomeKeyWindow
 {
-  return GDK_IS_TOPLEVEL (gdk_surface) ||
-         (GDK_IS_POPUP (gdk_surface) && GDK_SURFACE (gdk_surface)->input_region != NULL);
+  return GDK_IS_TOPLEVEL (gdk_surface);
 }
 
 -(void)showAndMakeKey:(BOOL)makeKey
